Main Development
----------------

The first version of swidGenerator was developed during a bachelor's thesis at
HSR University of Applied Sciences Rapperswil (http://www.hsr.ch/) in spring 2014.
Development continued in spring 2017 during a second bachelor's thesis.

- Christian Fässler (@cfaessler)
- Danilo Bargen (@dbrgn)
- Jonas Furrer (@d22)

- Davide De Giorgio (@degiorgioo)
- Christof Greiner (@Seperox)

- Andreas Steffen (@strongX509)

Other Contributions
-------------------

- Šimon Lukašík (@isimluk)
